# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class SegmentsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def explore_segments(self, bounds, **kwargs):  # noqa: E501
        """Explore segments  # noqa: E501

        Returns the top 10 segments matching a specified query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.explore_segments(bounds, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[float] bounds: The latitude and longitude for two points describing a rectangular boundary for the search: [southwest corner latitutde, southwest corner longitude, northeast corner latitude, northeast corner longitude] (required)
        :param str activity_type: Desired activity type.
        :param int min_cat: The minimum climbing category.
        :param int max_cat: The maximum climbing category.
        :return: ExplorerResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.explore_segments_with_http_info(bounds, **kwargs)  # noqa: E501
        else:
            (data) = self.explore_segments_with_http_info(bounds, **kwargs)  # noqa: E501
            return data

    def explore_segments_with_http_info(self, bounds, **kwargs):  # noqa: E501
        """Explore segments  # noqa: E501

        Returns the top 10 segments matching a specified query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.explore_segments_with_http_info(bounds, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[float] bounds: The latitude and longitude for two points describing a rectangular boundary for the search: [southwest corner latitutde, southwest corner longitude, northeast corner latitude, northeast corner longitude] (required)
        :param str activity_type: Desired activity type.
        :param int min_cat: The minimum climbing category.
        :param int max_cat: The maximum climbing category.
        :return: ExplorerResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bounds', 'activity_type', 'min_cat', 'max_cat']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method explore_segments" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bounds' is set
        if ('bounds' not in params or
                params['bounds'] is None):
            raise ValueError("Missing the required parameter `bounds` when calling `explore_segments`")  # noqa: E501

        if ('bounds' in params and
                len(params['bounds']) > 4):
            raise ValueError("Invalid value for parameter `bounds` when calling `explore_segments`, number of items must be less than or equal to `4`")  # noqa: E501
        if ('bounds' in params and
                len(params['bounds']) < 4):
            raise ValueError("Invalid value for parameter `bounds` when calling `explore_segments`, number of items must be greater than or equal to `4`")  # noqa: E501
        if 'min_cat' in params and params['min_cat'] > 5:  # noqa: E501
            raise ValueError("Invalid value for parameter `min_cat` when calling `explore_segments`, must be a value less than or equal to `5`")  # noqa: E501
        if 'min_cat' in params and params['min_cat'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `min_cat` when calling `explore_segments`, must be a value greater than or equal to `0`")  # noqa: E501
        if 'max_cat' in params and params['max_cat'] > 5:  # noqa: E501
            raise ValueError("Invalid value for parameter `max_cat` when calling `explore_segments`, must be a value less than or equal to `5`")  # noqa: E501
        if 'max_cat' in params and params['max_cat'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `max_cat` when calling `explore_segments`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'bounds' in params:
            query_params.append(('bounds', params['bounds']))  # noqa: E501
            collection_formats['bounds'] = 'csv'  # noqa: E501
        if 'activity_type' in params:
            query_params.append(('activity_type', params['activity_type']))  # noqa: E501
        if 'min_cat' in params:
            query_params.append(('min_cat', params['min_cat']))  # noqa: E501
        if 'max_cat' in params:
            query_params.append(('max_cat', params['max_cat']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/segments/explore', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ExplorerResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_leaderboard_by_segment_id(self, id, **kwargs):  # noqa: E501
        """Get Segment Leaderboard  # noqa: E501

        Returns the specified segment leaderboard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_leaderboard_by_segment_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the segment leaderboard. (required)
        :param str gender: Filter by gender.
        :param str age_group: Summit Feature. Filter by age group.
        :param str weight_class: Summit Feature. Filter by weight class.
        :param bool following: Filter by friends of the authenticated athlete.
        :param int club_id: Filter by club.
        :param str date_range: Filter by date range.
        :param int context_entries:
        :param int page: Page number.
        :param int per_page: Number of items per page. Defaults to 30.
        :return: SegmentLeaderboard
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_leaderboard_by_segment_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_leaderboard_by_segment_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_leaderboard_by_segment_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get Segment Leaderboard  # noqa: E501

        Returns the specified segment leaderboard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_leaderboard_by_segment_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the segment leaderboard. (required)
        :param str gender: Filter by gender.
        :param str age_group: Summit Feature. Filter by age group.
        :param str weight_class: Summit Feature. Filter by weight class.
        :param bool following: Filter by friends of the authenticated athlete.
        :param int club_id: Filter by club.
        :param str date_range: Filter by date range.
        :param int context_entries:
        :param int page: Page number.
        :param int per_page: Number of items per page. Defaults to 30.
        :return: SegmentLeaderboard
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'gender', 'age_group', 'weight_class', 'following', 'club_id', 'date_range', 'context_entries', 'page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_leaderboard_by_segment_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_leaderboard_by_segment_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'gender' in params:
            query_params.append(('gender', params['gender']))  # noqa: E501
        if 'age_group' in params:
            query_params.append(('age_group', params['age_group']))  # noqa: E501
        if 'weight_class' in params:
            query_params.append(('weight_class', params['weight_class']))  # noqa: E501
        if 'following' in params:
            query_params.append(('following', params['following']))  # noqa: E501
        if 'club_id' in params:
            query_params.append(('club_id', params['club_id']))  # noqa: E501
        if 'date_range' in params:
            query_params.append(('date_range', params['date_range']))  # noqa: E501
        if 'context_entries' in params:
            query_params.append(('context_entries', params['context_entries']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/segments/{id}/leaderboard', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SegmentLeaderboard',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_logged_in_athlete_starred_segments(self, **kwargs):  # noqa: E501
        """List Starred Segments  # noqa: E501

        List of the authenticated athlete's starred segments. Private segments are filtered out unless requested by a token with read_all scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_logged_in_athlete_starred_segments(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Page number.
        :param int per_page: Number of items per page. Defaults to 30.
        :return: list[SummarySegment]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_logged_in_athlete_starred_segments_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_logged_in_athlete_starred_segments_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_logged_in_athlete_starred_segments_with_http_info(self, **kwargs):  # noqa: E501
        """List Starred Segments  # noqa: E501

        List of the authenticated athlete's starred segments. Private segments are filtered out unless requested by a token with read_all scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_logged_in_athlete_starred_segments_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Page number.
        :param int per_page: Number of items per page. Defaults to 30.
        :return: list[SummarySegment]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_logged_in_athlete_starred_segments" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/segments/starred', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[SummarySegment]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_segment_by_id(self, id, **kwargs):  # noqa: E501
        """Get Segment  # noqa: E501

        Returns the specified segment. read_all scope required in order to retrieve athlete-specific segment information, or to retrieve private segments.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_segment_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the segment. (required)
        :return: DetailedSegment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_segment_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_segment_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_segment_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get Segment  # noqa: E501

        Returns the specified segment. read_all scope required in order to retrieve athlete-specific segment information, or to retrieve private segments.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_segment_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the segment. (required)
        :return: DetailedSegment
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_segment_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_segment_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/segments/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DetailedSegment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def star_segment(self, id, starred, **kwargs):  # noqa: E501
        """Star Segment  # noqa: E501

        Stars/Unstars the given segment for the authenticated athlete. Requires profile:write scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.star_segment(id, starred, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the segment to star. (required)
        :param bool starred: If true, star the segment; if false, unstar the segment. (required)
        :return: DetailedSegment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.star_segment_with_http_info(id, starred, **kwargs)  # noqa: E501
        else:
            (data) = self.star_segment_with_http_info(id, starred, **kwargs)  # noqa: E501
            return data

    def star_segment_with_http_info(self, id, starred, **kwargs):  # noqa: E501
        """Star Segment  # noqa: E501

        Stars/Unstars the given segment for the authenticated athlete. Requires profile:write scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.star_segment_with_http_info(id, starred, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the segment to star. (required)
        :param bool starred: If true, star the segment; if false, unstar the segment. (required)
        :return: DetailedSegment
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'starred']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method star_segment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `star_segment`")  # noqa: E501
        # verify the required parameter 'starred' is set
        if ('starred' not in params or
                params['starred'] is None):
            raise ValueError("Missing the required parameter `starred` when calling `star_segment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'starred' in params:
            form_params.append(('starred', params['starred']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/segments/{id}/starred', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DetailedSegment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.activity_total import ActivityTotal  # noqa: F401,E501


class ActivityStats(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'biggest_ride_distance': 'float',
        'biggest_climb_elevation_gain': 'float',
        'recent_ride_totals': 'ActivityTotal',
        'recent_run_totals': 'ActivityTotal',
        'recent_swim_totals': 'ActivityTotal',
        'ytd_ride_totals': 'ActivityTotal',
        'ytd_run_totals': 'ActivityTotal',
        'ytd_swim_totals': 'ActivityTotal',
        'all_ride_totals': 'ActivityTotal',
        'all_run_totals': 'ActivityTotal',
        'all_swim_totals': 'ActivityTotal'
    }

    attribute_map = {
        'biggest_ride_distance': 'biggest_ride_distance',
        'biggest_climb_elevation_gain': 'biggest_climb_elevation_gain',
        'recent_ride_totals': 'recent_ride_totals',
        'recent_run_totals': 'recent_run_totals',
        'recent_swim_totals': 'recent_swim_totals',
        'ytd_ride_totals': 'ytd_ride_totals',
        'ytd_run_totals': 'ytd_run_totals',
        'ytd_swim_totals': 'ytd_swim_totals',
        'all_ride_totals': 'all_ride_totals',
        'all_run_totals': 'all_run_totals',
        'all_swim_totals': 'all_swim_totals'
    }

    def __init__(self, biggest_ride_distance=None, biggest_climb_elevation_gain=None, recent_ride_totals=None, recent_run_totals=None, recent_swim_totals=None, ytd_ride_totals=None, ytd_run_totals=None, ytd_swim_totals=None, all_ride_totals=None, all_run_totals=None, all_swim_totals=None):  # noqa: E501
        """ActivityStats - a model defined in Swagger"""  # noqa: E501

        self._biggest_ride_distance = None
        self._biggest_climb_elevation_gain = None
        self._recent_ride_totals = None
        self._recent_run_totals = None
        self._recent_swim_totals = None
        self._ytd_ride_totals = None
        self._ytd_run_totals = None
        self._ytd_swim_totals = None
        self._all_ride_totals = None
        self._all_run_totals = None
        self._all_swim_totals = None
        self.discriminator = None

        if biggest_ride_distance is not None:
            self.biggest_ride_distance = biggest_ride_distance
        if biggest_climb_elevation_gain is not None:
            self.biggest_climb_elevation_gain = biggest_climb_elevation_gain
        if recent_ride_totals is not None:
            self.recent_ride_totals = recent_ride_totals
        if recent_run_totals is not None:
            self.recent_run_totals = recent_run_totals
        if recent_swim_totals is not None:
            self.recent_swim_totals = recent_swim_totals
        if ytd_ride_totals is not None:
            self.ytd_ride_totals = ytd_ride_totals
        if ytd_run_totals is not None:
            self.ytd_run_totals = ytd_run_totals
        if ytd_swim_totals is not None:
            self.ytd_swim_totals = ytd_swim_totals
        if all_ride_totals is not None:
            self.all_ride_totals = all_ride_totals
        if all_run_totals is not None:
            self.all_run_totals = all_run_totals
        if all_swim_totals is not None:
            self.all_swim_totals = all_swim_totals

    @property
    def biggest_ride_distance(self):
        """Gets the biggest_ride_distance of this ActivityStats.  # noqa: E501

        The longest distance ridden by the athlete.  # noqa: E501

        :return: The biggest_ride_distance of this ActivityStats.  # noqa: E501
        :rtype: float
        """
        return self._biggest_ride_distance

    @biggest_ride_distance.setter
    def biggest_ride_distance(self, biggest_ride_distance):
        """Sets the biggest_ride_distance of this ActivityStats.

        The longest distance ridden by the athlete.  # noqa: E501

        :param biggest_ride_distance: The biggest_ride_distance of this ActivityStats.  # noqa: E501
        :type: float
        """

        self._biggest_ride_distance = biggest_ride_distance

    @property
    def biggest_climb_elevation_gain(self):
        """Gets the biggest_climb_elevation_gain of this ActivityStats.  # noqa: E501

        The highest climb ridden by the athlete.  # noqa: E501

        :return: The biggest_climb_elevation_gain of this ActivityStats.  # noqa: E501
        :rtype: float
        """
        return self._biggest_climb_elevation_gain

    @biggest_climb_elevation_gain.setter
    def biggest_climb_elevation_gain(self, biggest_climb_elevation_gain):
        """Sets the biggest_climb_elevation_gain of this ActivityStats.

        The highest climb ridden by the athlete.  # noqa: E501

        :param biggest_climb_elevation_gain: The biggest_climb_elevation_gain of this ActivityStats.  # noqa: E501
        :type: float
        """

        self._biggest_climb_elevation_gain = biggest_climb_elevation_gain

    @property
    def recent_ride_totals(self):
        """Gets the recent_ride_totals of this ActivityStats.  # noqa: E501

        The recent (last 4 weeks) ride stats for the athlete.  # noqa: E501

        :return: The recent_ride_totals of this ActivityStats.  # noqa: E501
        :rtype: ActivityTotal
        """
        return self._recent_ride_totals

    @recent_ride_totals.setter
    def recent_ride_totals(self, recent_ride_totals):
        """Sets the recent_ride_totals of this ActivityStats.

        The recent (last 4 weeks) ride stats for the athlete.  # noqa: E501

        :param recent_ride_totals: The recent_ride_totals of this ActivityStats.  # noqa: E501
        :type: ActivityTotal
        """

        self._recent_ride_totals = recent_ride_totals

    @property
    def recent_run_totals(self):
        """Gets the recent_run_totals of this ActivityStats.  # noqa: E501

        The recent (last 4 weeks) run stats for the athlete.  # noqa: E501

        :return: The recent_run_totals of this ActivityStats.  # noqa: E501
        :rtype: ActivityTotal
        """
        return self._recent_run_totals

    @recent_run_totals.setter
    def recent_run_totals(self, recent_run_totals):
        """Sets the recent_run_totals of this ActivityStats.

        The recent (last 4 weeks) run stats for the athlete.  # noqa: E501

        :param recent_run_totals: The recent_run_totals of this ActivityStats.  # noqa: E501
        :type: ActivityTotal
        """

        self._recent_run_totals = recent_run_totals

    @property
    def recent_swim_totals(self):
        """Gets the recent_swim_totals of this ActivityStats.  # noqa: E501

        The recent (last 4 weeks) swim stats for the athlete.  # noqa: E501

        :return: The recent_swim_totals of this ActivityStats.  # noqa: E501
        :rtype: ActivityTotal
        """
        return self._recent_swim_totals

    @recent_swim_totals.setter
    def recent_swim_totals(self, recent_swim_totals):
        """Sets the recent_swim_totals of this ActivityStats.

        The recent (last 4 weeks) swim stats for the athlete.  # noqa: E501

        :param recent_swim_totals: The recent_swim_totals of this ActivityStats.  # noqa: E501
        :type: ActivityTotal
        """

        self._recent_swim_totals = recent_swim_totals

    @property
    def ytd_ride_totals(self):
        """Gets the ytd_ride_totals of this ActivityStats.  # noqa: E501

        The year to date ride stats for the athlete.  # noqa: E501

        :return: The ytd_ride_totals of this ActivityStats.  # noqa: E501
        :rtype: ActivityTotal
        """
        return self._ytd_ride_totals

    @ytd_ride_totals.setter
    def ytd_ride_totals(self, ytd_ride_totals):
        """Sets the ytd_ride_totals of this ActivityStats.

        The year to date ride stats for the athlete.  # noqa: E501

        :param ytd_ride_totals: The ytd_ride_totals of this ActivityStats.  # noqa: E501
        :type: ActivityTotal
        """

        self._ytd_ride_totals = ytd_ride_totals

    @property
    def ytd_run_totals(self):
        """Gets the ytd_run_totals of this ActivityStats.  # noqa: E501

        The year to date run stats for the athlete.  # noqa: E501

        :return: The ytd_run_totals of this ActivityStats.  # noqa: E501
        :rtype: ActivityTotal
        """
        return self._ytd_run_totals

    @ytd_run_totals.setter
    def ytd_run_totals(self, ytd_run_totals):
        """Sets the ytd_run_totals of this ActivityStats.

        The year to date run stats for the athlete.  # noqa: E501

        :param ytd_run_totals: The ytd_run_totals of this ActivityStats.  # noqa: E501
        :type: ActivityTotal
        """

        self._ytd_run_totals = ytd_run_totals

    @property
    def ytd_swim_totals(self):
        """Gets the ytd_swim_totals of this ActivityStats.  # noqa: E501

        The year to date swim stats for the athlete.  # noqa: E501

        :return: The ytd_swim_totals of this ActivityStats.  # noqa: E501
        :rtype: ActivityTotal
        """
        return self._ytd_swim_totals

    @ytd_swim_totals.setter
    def ytd_swim_totals(self, ytd_swim_totals):
        """Sets the ytd_swim_totals of this ActivityStats.

        The year to date swim stats for the athlete.  # noqa: E501

        :param ytd_swim_totals: The ytd_swim_totals of this ActivityStats.  # noqa: E501
        :type: ActivityTotal
        """

        self._ytd_swim_totals = ytd_swim_totals

    @property
    def all_ride_totals(self):
        """Gets the all_ride_totals of this ActivityStats.  # noqa: E501

        The all time ride stats for the athlete.  # noqa: E501

        :return: The all_ride_totals of this ActivityStats.  # noqa: E501
        :rtype: ActivityTotal
        """
        return self._all_ride_totals

    @all_ride_totals.setter
    def all_ride_totals(self, all_ride_totals):
        """Sets the all_ride_totals of this ActivityStats.

        The all time ride stats for the athlete.  # noqa: E501

        :param all_ride_totals: The all_ride_totals of this ActivityStats.  # noqa: E501
        :type: ActivityTotal
        """

        self._all_ride_totals = all_ride_totals

    @property
    def all_run_totals(self):
        """Gets the all_run_totals of this ActivityStats.  # noqa: E501

        The all time run stats for the athlete.  # noqa: E501

        :return: The all_run_totals of this ActivityStats.  # noqa: E501
        :rtype: ActivityTotal
        """
        return self._all_run_totals

    @all_run_totals.setter
    def all_run_totals(self, all_run_totals):
        """Sets the all_run_totals of this ActivityStats.

        The all time run stats for the athlete.  # noqa: E501

        :param all_run_totals: The all_run_totals of this ActivityStats.  # noqa: E501
        :type: ActivityTotal
        """

        self._all_run_totals = all_run_totals

    @property
    def all_swim_totals(self):
        """Gets the all_swim_totals of this ActivityStats.  # noqa: E501

        The all time swim stats for the athlete.  # noqa: E501

        :return: The all_swim_totals of this ActivityStats.  # noqa: E501
        :rtype: ActivityTotal
        """
        return self._all_swim_totals

    @all_swim_totals.setter
    def all_swim_totals(self, all_swim_totals):
        """Sets the all_swim_totals of this ActivityStats.

        The all time swim stats for the athlete.  # noqa: E501

        :param all_swim_totals: The all_swim_totals of this ActivityStats.  # noqa: E501
        :type: ActivityTotal
        """

        self._all_swim_totals = all_swim_totals

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityStats, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityStats):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.summary_athlete import SummaryAthlete  # noqa: F401,E501


class Comment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'activity_id': 'int',
        'text': 'str',
        'athlete': 'SummaryAthlete',
        'created_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'activity_id': 'activity_id',
        'text': 'text',
        'athlete': 'athlete',
        'created_at': 'created_at'
    }

    def __init__(self, id=None, activity_id=None, text=None, athlete=None, created_at=None):  # noqa: E501
        """Comment - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._activity_id = None
        self._text = None
        self._athlete = None
        self._created_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if activity_id is not None:
            self.activity_id = activity_id
        if text is not None:
            self.text = text
        if athlete is not None:
            self.athlete = athlete
        if created_at is not None:
            self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this Comment.  # noqa: E501

        The unique identifier of this comment  # noqa: E501

        :return: The id of this Comment.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Comment.

        The unique identifier of this comment  # noqa: E501

        :param id: The id of this Comment.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def activity_id(self):
        """Gets the activity_id of this Comment.  # noqa: E501

        The identifier of the activity this comment is related to  # noqa: E501

        :return: The activity_id of this Comment.  # noqa: E501
        :rtype: int
        """
        return self._activity_id

    @activity_id.setter
    def activity_id(self, activity_id):
        """Sets the activity_id of this Comment.

        The identifier of the activity this comment is related to  # noqa: E501

        :param activity_id: The activity_id of this Comment.  # noqa: E501
        :type: int
        """

        self._activity_id = activity_id

    @property
    def text(self):
        """Gets the text of this Comment.  # noqa: E501

        The content of the comment  # noqa: E501

        :return: The text of this Comment.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this Comment.

        The content of the comment  # noqa: E501

        :param text: The text of this Comment.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def athlete(self):
        """Gets the athlete of this Comment.  # noqa: E501


        :return: The athlete of this Comment.  # noqa: E501
        :rtype: SummaryAthlete
        """
        return self._athlete

    @athlete.setter
    def athlete(self, athlete):
        """Sets the athlete of this Comment.


        :param athlete: The athlete of this Comment.  # noqa: E501
        :type: SummaryAthlete
        """

        self._athlete = athlete

    @property
    def created_at(self):
        """Gets the created_at of this Comment.  # noqa: E501

        The time at which this comment was created.  # noqa: E501

        :return: The created_at of this Comment.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Comment.

        The time at which this comment was created.  # noqa: E501

        :param created_at: The created_at of this Comment.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Comment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Comment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SummarySegmentEffort(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'elapsed_time': 'int',
        'start_date': 'datetime',
        'start_date_local': 'datetime',
        'distance': 'float',
        'is_kom': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'elapsed_time': 'elapsed_time',
        'start_date': 'start_date',
        'start_date_local': 'start_date_local',
        'distance': 'distance',
        'is_kom': 'is_kom'
    }

    def __init__(self, id=None, elapsed_time=None, start_date=None, start_date_local=None, distance=None, is_kom=None):  # noqa: E501
        """SummarySegmentEffort - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._elapsed_time = None
        self._start_date = None
        self._start_date_local = None
        self._distance = None
        self._is_kom = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if elapsed_time is not None:
            self.elapsed_time = elapsed_time
        if start_date is not None:
            self.start_date = start_date
        if start_date_local is not None:
            self.start_date_local = start_date_local
        if distance is not None:
            self.distance = distance
        if is_kom is not None:
            self.is_kom = is_kom

    @property
    def id(self):
        """Gets the id of this SummarySegmentEffort.  # noqa: E501

        The unique identifier of this effort  # noqa: E501

        :return: The id of this SummarySegmentEffort.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SummarySegmentEffort.

        The unique identifier of this effort  # noqa: E501

        :param id: The id of this SummarySegmentEffort.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def elapsed_time(self):
        """Gets the elapsed_time of this SummarySegmentEffort.  # noqa: E501

        The effort's elapsed time  # noqa: E501

        :return: The elapsed_time of this SummarySegmentEffort.  # noqa: E501
        :rtype: int
        """
        return self._elapsed_time

    @elapsed_time.setter
    def elapsed_time(self, elapsed_time):
        """Sets the elapsed_time of this SummarySegmentEffort.

        The effort's elapsed time  # noqa: E501

        :param elapsed_time: The elapsed_time of this SummarySegmentEffort.  # noqa: E501
        :type: int
        """

        self._elapsed_time = elapsed_time

    @property
    def start_date(self):
        """Gets the start_date of this SummarySegmentEffort.  # noqa: E501

        The time at which the effort was started.  # noqa: E501

        :return: The start_date of this SummarySegmentEffort.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this SummarySegmentEffort.

        The time at which the effort was started.  # noqa: E501

        :param start_date: The start_date of this SummarySegmentEffort.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def start_date_local(self):
        """Gets the start_date_local of this SummarySegmentEffort.  # noqa: E501

        The time at which the effort was started in the local timezone.  # noqa: E501

        :return: The start_date_local of this SummarySegmentEffort.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date_local

    @start_date_local.setter
    def start_date_local(self, start_date_local):
        """Sets the start_date_local of this SummarySegmentEffort.

        The time at which the effort was started in the local timezone.  # noqa: E501

        :param start_date_local: The start_date_local of this SummarySegmentEffort.  # noqa: E501
        :type: datetime
        """

        self._start_date_local = start_date_local

    @property
    def distance(self):
        """Gets the distance of this SummarySegmentEffort.  # noqa: E501

        The effort's distance in meters  # noqa: E501

        :return: The distance of this SummarySegmentEffort.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this SummarySegmentEffort.

        The effort's distance in meters  # noqa: E501

        :param distance: The distance of this SummarySegmentEffort.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def is_kom(self):
        """Gets the is_kom of this SummarySegmentEffort.  # noqa: E501

        Whether this effort is the current best on the leaderboard  # noqa: E501

        :return: The is_kom of this SummarySegmentEffort.  # noqa: E501
        :rtype: bool
        """
        return self._is_kom

    @is_kom.setter
    def is_kom(self, is_kom):
        """Sets the is_kom of this SummarySegmentEffort.

        Whether this effort is the current best on the leaderboard  # noqa: E501

        :param is_kom: The is_kom of this SummarySegmentEffort.  # noqa: E501
        :type: bool
        """

        self._is_kom = is_kom

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SummarySegmentEffort, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SummarySegmentEffort):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RunningRace(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'running_race_type': 'int',
        'distance': 'float',
        'start_date_local': 'datetime',
        'city': 'str',
        'state': 'str',
        'country': 'str',
        'route_ids': 'list[int]',
        'measurement_preference': 'str',
        'url': 'str',
        'website_url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'running_race_type': 'running_race_type',
        'distance': 'distance',
        'start_date_local': 'start_date_local',
        'city': 'city',
        'state': 'state',
        'country': 'country',
        'route_ids': 'route_ids',
        'measurement_preference': 'measurement_preference',
        'url': 'url',
        'website_url': 'website_url'
    }

    def __init__(self, id=None, name=None, running_race_type=None, distance=None, start_date_local=None, city=None, state=None, country=None, route_ids=None, measurement_preference=None, url=None, website_url=None):  # noqa: E501
        """RunningRace - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._running_race_type = None
        self._distance = None
        self._start_date_local = None
        self._city = None
        self._state = None
        self._country = None
        self._route_ids = None
        self._measurement_preference = None
        self._url = None
        self._website_url = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if running_race_type is not None:
            self.running_race_type = running_race_type
        if distance is not None:
            self.distance = distance
        if start_date_local is not None:
            self.start_date_local = start_date_local
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if route_ids is not None:
            self.route_ids = route_ids
        if measurement_preference is not None:
            self.measurement_preference = measurement_preference
        if url is not None:
            self.url = url
        if website_url is not None:
            self.website_url = website_url

    @property
    def id(self):
        """Gets the id of this RunningRace.  # noqa: E501

        The unique identifier of this race.  # noqa: E501

        :return: The id of this RunningRace.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RunningRace.

        The unique identifier of this race.  # noqa: E501

        :param id: The id of this RunningRace.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this RunningRace.  # noqa: E501

        The name of this race.  # noqa: E501

        :return: The name of this RunningRace.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RunningRace.

        The name of this race.  # noqa: E501

        :param name: The name of this RunningRace.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def running_race_type(self):
        """Gets the running_race_type of this RunningRace.  # noqa: E501

        The type of this race.  # noqa: E501

        :return: The running_race_type of this RunningRace.  # noqa: E501
        :rtype: int
        """
        return self._running_race_type

    @running_race_type.setter
    def running_race_type(self, running_race_type):
        """Sets the running_race_type of this RunningRace.

        The type of this race.  # noqa: E501

        :param running_race_type: The running_race_type of this RunningRace.  # noqa: E501
        :type: int
        """

        self._running_race_type = running_race_type

    @property
    def distance(self):
        """Gets the distance of this RunningRace.  # noqa: E501

        The race's distance, in meters.  # noqa: E501

        :return: The distance of this RunningRace.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this RunningRace.

        The race's distance, in meters.  # noqa: E501

        :param distance: The distance of this RunningRace.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def start_date_local(self):
        """Gets the start_date_local of this RunningRace.  # noqa: E501

        The time at which the race begins started in the local timezone.  # noqa: E501

        :return: The start_date_local of this RunningRace.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date_local

    @start_date_local.setter
    def start_date_local(self, start_date_local):
        """Sets the start_date_local of this RunningRace.

        The time at which the race begins started in the local timezone.  # noqa: E501

        :param start_date_local: The start_date_local of this RunningRace.  # noqa: E501
        :type: datetime
        """

        self._start_date_local = start_date_local

    @property
    def city(self):
        """Gets the city of this RunningRace.  # noqa: E501

        The name of the city in which the race is taking place.  # noqa: E501

        :return: The city of this RunningRace.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this RunningRace.

        The name of the city in which the race is taking place.  # noqa: E501

        :param city: The city of this RunningRace.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this RunningRace.  # noqa: E501

        The name of the state or geographical region in which the race is taking place.  # noqa: E501

        :return: The state of this RunningRace.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this RunningRace.

        The name of the state or geographical region in which the race is taking place.  # noqa: E501

        :param state: The state of this RunningRace.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this RunningRace.  # noqa: E501

        The name of the country in which the race is taking place.  # noqa: E501

        :return: The country of this RunningRace.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this RunningRace.

        The name of the country in which the race is taking place.  # noqa: E501

        :param country: The country of this RunningRace.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def route_ids(self):
        """Gets the route_ids of this RunningRace.  # noqa: E501

        The set of routes that cover this race's course.  # noqa: E501

        :return: The route_ids of this RunningRace.  # noqa: E501
        :rtype: list[int]
        """
        return self._route_ids

    @route_ids.setter
    def route_ids(self, route_ids):
        """Sets the route_ids of this RunningRace.

        The set of routes that cover this race's course.  # noqa: E501

        :param route_ids: The route_ids of this RunningRace.  # noqa: E501
        :type: list[int]
        """

        self._route_ids = route_ids

    @property
    def measurement_preference(self):
        """Gets the measurement_preference of this RunningRace.  # noqa: E501

        The unit system in which the race should be displayed.  # noqa: E501

        :return: The measurement_preference of this RunningRace.  # noqa: E501
        :rtype: str
        """
        return self._measurement_preference

    @measurement_preference.setter
    def measurement_preference(self, measurement_preference):
        """Sets the measurement_preference of this RunningRace.

        The unit system in which the race should be displayed.  # noqa: E501

        :param measurement_preference: The measurement_preference of this RunningRace.  # noqa: E501
        :type: str
        """
        allowed_values = ["feet", "meters"]  # noqa: E501
        if measurement_preference not in allowed_values:
            raise ValueError(
                "Invalid value for `measurement_preference` ({0}), must be one of {1}"  # noqa: E501
                .format(measurement_preference, allowed_values)
            )

        self._measurement_preference = measurement_preference

    @property
    def url(self):
        """Gets the url of this RunningRace.  # noqa: E501

        The vanity URL of this race on Strava.  # noqa: E501

        :return: The url of this RunningRace.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this RunningRace.

        The vanity URL of this race on Strava.  # noqa: E501

        :param url: The url of this RunningRace.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def website_url(self):
        """Gets the website_url of this RunningRace.  # noqa: E501

        The URL of this race's website.  # noqa: E501

        :return: The website_url of this RunningRace.  # noqa: E501
        :rtype: str
        """
        return self._website_url

    @website_url.setter
    def website_url(self, website_url):
        """Sets the website_url of this RunningRace.

        The URL of this race's website.  # noqa: E501

        :param website_url: The website_url of this RunningRace.  # noqa: E501
        :type: str
        """

        self._website_url = website_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RunningRace, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunningRace):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RouteDirection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'distance': 'float',
        'action': 'int',
        'name': 'str'
    }

    attribute_map = {
        'distance': 'distance',
        'action': 'action',
        'name': 'name'
    }

    def __init__(self, distance=None, action=None, name=None):  # noqa: E501
        """RouteDirection - a model defined in Swagger"""  # noqa: E501

        self._distance = None
        self._action = None
        self._name = None
        self.discriminator = None

        if distance is not None:
            self.distance = distance
        if action is not None:
            self.action = action
        if name is not None:
            self.name = name

    @property
    def distance(self):
        """Gets the distance of this RouteDirection.  # noqa: E501

        The distance in the route at which the action applies  # noqa: E501

        :return: The distance of this RouteDirection.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this RouteDirection.

        The distance in the route at which the action applies  # noqa: E501

        :param distance: The distance of this RouteDirection.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def action(self):
        """Gets the action of this RouteDirection.  # noqa: E501

        The action of this direction  # noqa: E501

        :return: The action of this RouteDirection.  # noqa: E501
        :rtype: int
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this RouteDirection.

        The action of this direction  # noqa: E501

        :param action: The action of this RouteDirection.  # noqa: E501
        :type: int
        """

        self._action = action

    @property
    def name(self):
        """Gets the name of this RouteDirection.  # noqa: E501


        :return: The name of this RouteDirection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RouteDirection.


        :param name: The name of this RouteDirection.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RouteDirection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RouteDirection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
